@@ -1,5 +1,5 @@
 <?php
-// $Id: index.php,v 1.2.6.2 2005/05/31 03:48:18 nobunobu Exp $
+// $Id: index.php,v 1.4 2005/08/03 12:39:12 onokazu Exp $
 //  ------------------------------------------------------------------------ //
 //                XOOPS - PHP Content Management System                      //
 //                    Copyright (c) 2000 XOOPS.org                           //
@@ -145,7 +145,7 @@ function listNewDownloads()
             echo "<br /><input type=\"hidden\" name=\"op\" value=\"approve\"></input>";
             echo "<input type=\"hidden\" name=\"lid\" value=\"$lid\" />";
             echo "<input type=\"submit\" value=\""._MD_APPROVE."\" /></form>\n";
-            echo myTextForm("index.php?op=delNewDownload&lid=$lid",_MD_DELETE);
+            echo myTextForm("index.php?op=delNewDownload&amp;lid=$lid",_MD_DELETE);
             echo "<br /><br />";
         }
     }else{
@@ -327,7 +327,7 @@ function modDownload()
     echo "<input type='hidden' name='op' value='modDownloadS' /><input type='submit' value='"._MD_SUBMIT."' />";
     echo "</form>\n";
     echo "<table><tr><td>\n";
-    echo myTextForm("index.php?op=delDownload&lid=".$lid , _MD_DELETE);
+    echo myTextForm("index.php?op=delDownload&amp;lid=".$lid , _MD_DELETE);
     echo "</td><td>\n";
     echo myTextForm("index.php?op=downloadsConfigMenu", _MD_CANCEL);
     echo "</td></tr></table>\n";
@@ -363,11 +363,11 @@ function modDownload()
         $useravgrating = $useravgrating / $uservotes;
         $useravgrating = number_format($useravgrating, 1);
         $ratinguname = XoopsUser::getUnameFromId($ratinguser);
-        // echo "<tr><td bgcolor=\"$colorswitch\">$ratinguname</td><td bgcolor=\"$colorswitch\">$ratinghostname</td><td bgcolor=\"$colorswitch\">$rating</td><td bgcolor=\"$colorswitch\">$useravgrating</td><td bgcolor=\"$colorswitch\">$uservotes</td><td bgcolor=\"$colorswitch\">$formatted_date</td><td bgcolor=\"$colorswitch\" align=\"center\"><b><a href=index.php?op=delVote&lid=$lid&rid=$ratingid>X</a></b></td></tr>\n";
+        // echo "<tr><td bgcolor=\"$colorswitch\">$ratinguname</td><td bgcolor=\"$colorswitch\">$ratinghostname</td><td bgcolor=\"$colorswitch\">$rating</td><td bgcolor=\"$colorswitch\">$useravgrating</td><td bgcolor=\"$colorswitch\">$uservotes</td><td bgcolor=\"$colorswitch\">$formatted_date</td><td bgcolor=\"$colorswitch\" align=\"center\"><b><a href=index.php?op=delVote&amp;lid=$lid&amp;rid=$ratingid>X</a></b></td></tr>\n";
         // echo "<tr><td bgcolor=\"$colorswitch\">$ratinguname</td><td bgcolor=\"$colorswitch\">$ratinghostname</td><td bgcolor=\"$colorswitch\">$rating</td><td bgcolor=\"$colorswitch\">$useravgrating</td><td bgcolor=\"$colorswitch\">$uservotes</td><td bgcolor=\"$colorswitch\">$formatted_date</td><td bgcolor=\"$colorswitch\" align=\"center\">";
         echo "<tr><td bgcolor=\"$colorswitch\">$ratinguname</td><td bgcolor=\"$colorswitch\">$ratinghostname</td><td bgcolor=\"$colorswitch\">$rating</td><td bgcolor=\"$colorswitch\">$useravgrating</td><td bgcolor=\"$colorswitch\">$uservotes</td><td bgcolor=\"$colorswitch\">$formatted_date</td><td bgcolor=\"$colorswitch\" align=\"center\">";
         //echo "<table><tr><td>\n";
-        echo myTextForm("index.php?op=delVote&lid=$lid&rid=$ratingid" , "X");
+        echo myTextForm("index.php?op=delVote&amp;lid=$lid&amp;rid=$ratingid" , "X");
         // echo "</td></tr></table>\n";
         echo "</td></tr>\n";
 
@@ -393,11 +393,11 @@ function modDownload()
     $colorswitch="dddddd";
     while(list($ratingid, $rating, $ratinghostname, $ratingtimestamp)=$xoopsDB->fetchRow($result5)) {
         $formatted_date = formatTimestamp($ratingtimestamp);
-        // echo "<td colspan=\"2\" bgcolor=\"$colorswitch\">$ratinghostname</td><td colspan=\"3\" bgcolor=\"$colorswitch\">$rating</td><td bgcolor=\"$colorswitch\">$formatted_date</td><td bgcolor=\"$colorswitch\" aling=\"center\"><b><a href=index.php?op=delVote&lid=$lid&rid=$ratingid>X</a></b></td></tr>";
+        // echo "<td colspan=\"2\" bgcolor=\"$colorswitch\">$ratinghostname</td><td colspan=\"3\" bgcolor=\"$colorswitch\">$rating</td><td bgcolor=\"$colorswitch\">$formatted_date</td><td bgcolor=\"$colorswitch\" aling=\"center\"><b><a href=index.php?op=delVote&amp;lid=$lid&amp;rid=$ratingid>X</a></b></td></tr>";
         echo "<td colspan=\"2\" bgcolor=\"$colorswitch\">$ratinghostname</td><td colspan=\"3\" bgcolor=\"$colorswitch\">$rating</td><td bgcolor=\"$colorswitch\">$formatted_date</td><td bgcolor=\"$colorswitch\" align=\"center\">";
         //echo "<table><tr><td>\n";
         //align=\"center\"
-        echo myTextForm("index.php?op=delVote&lid=$lid&rid=$ratingid" , "X");
+        echo myTextForm("index.php?op=delVote&amp;lid=$lid&amp;rid=$ratingid" , "X");
         //echo "</td></tr></table>\n";
 
         echo "</td></tr>";
@@ -474,11 +474,11 @@ function listBrokenDownloads()
                 echo "<td bgcolor='$colorswitch'><a href='mailto:$owneremail'>$ownername</a>";
             }
             echo "</td><td bgcolor='$colorswitch' align='center'>\n";
-            echo myTextForm("index.php?op=ignoreBrokenDownloads&lid=$lid" , "X");
+            echo myTextForm("index.php?op=ignoreBrokenDownloads&amp;lid=$lid" , "X");
             echo "</td><td bgcolor='$colorswitch' align='center'>\n";
-            echo myTextForm("index.php?op=modDownload&lid=$lid" , "X");
+            echo myTextForm("index.php?op=modDownload&amp;lid=$lid" , "X");
             echo "</td><td bgcolor='$colorswitch' align='center'>\n";
-            echo myTextForm("index.php?op=delBrokenDownloads&lid=$lid" , "X");
+            echo myTextForm("index.php?op=delBrokenDownloads&amp;lid=$lid" , "X");
             echo "</td></tr>\n";
             if ($colorswitch=="#dddddd") {
                 $colorswitch="#ffffff";
@@ -611,11 +611,11 @@ function listModReq()
             }
             echo "<td align='right'><small>\n";
             echo "<table><tr><td>\n";
-            echo myTextForm("index.php?op=changeModReq&requestid=$requestid" , _MD_APPROVE);
+            echo myTextForm("index.php?op=changeModReq&amp;requestid=$requestid" , _MD_APPROVE);
             echo "</td><td>\n";
-            echo myTextForm("index.php?op=modDownload&lid=$lookup_lid[$requestid]", _EDIT);
+            echo myTextForm("index.php?op=modDownload&amp;lid=$lookup_lid[$requestid]", _EDIT);
             echo "</td><td>\n";
-            echo myTextForm("index.php?op=ignoreModReq&requestid=$requestid", _MD_IGNORE);
+            echo myTextForm("index.php?op=ignoreModReq&amp;requestid=$requestid", _MD_IGNORE);
             echo "</td></tr></table>\n";
             echo "</small></td></tr>\n";
             echo "</table><br /><br />";
